Listener

Struct Listener 

pub struct Listener<State, Event>(/* private fields */);
A weak reference to a callback function (usually Callback) which is notified of changes to Store State, and Events produced by the store.

See Callback for more information about how this is typically used.

Implementations

Source

impl<State, Event> Listener<State, Event>

pub fn as_callback(&self) -> Option<Callback<State, Event>>

Attempt to upgrade the weak reference in this listener to a Callback, otherwise if unable to, returns None.